@@ -38,6 +38,24 @@ class Puppet::Provider::Nova < Puppet::Provider::Openstack
     Puppet::Provider::Openstack.request(service, action, properties, @credentials)
   end
 
+  def self.nova_manage_request(*args)
+    # Not using the nova-manage command directly,
+    # so we can disable combining of stderr/stdout output.
+    args.unshift(Puppet::Util.which('nova-manage'))
+
+    # NOTE(mnaser): We pass the arguments as an array to avoid problems with
+    #               symbols in the arguments breaking things.
+    Puppet::Util::Execution.execute(args, {
+      :failonfail         => true,
+      :combine            => false,
+      :custom_environment => {}
+    })
+  end
+
+  def nova_manage_request(*args)
+    self.class.nova_manage_request(args)
+  end
+
   def self.conf_filename
     '/etc/nova/nova.conf'
   end
