@@ -59,6 +59,11 @@ describe 'nova::compute' do
         is_expected.to contain_package('genisoimage').that_requires('Anchor[nova::install::begin]')
         is_expected.to contain_package('genisoimage').that_comes_before('Anchor[nova::install::end]')
       end
+
+      it 'configures nova pci_passthrough_whitelist' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
+      end
     end
 
     context 'with overridden parameters' do
@@ -73,7 +78,6 @@ describe 'nova::compute' do
           :default_schedule_zone              => 'az2',
           :internal_service_availability_zone => 'az_int1',
           :heal_instance_info_cache_interval  => '120',
-          :pci_passthrough                    => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
           :config_drive_format                => 'vfat',
           :resize_confirm_window              => '3',
           :vcpu_pin_set                       => ['4-12','^8','15'],
@@ -141,12 +145,6 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
 
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_nova_config('DEFAULT/pci_passthrough_whitelist').with(
-          'value' => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]"
-        )
-      end
-
       it 'configures nova config_drive_format to vfat' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
         is_expected.to_not contain_package('genisoimage').with(
@@ -155,18 +153,58 @@ describe 'nova::compute' do
       end
     end
 
+    context 'with pci params array' do
+      let :params do
+        {
+          :pci_passthrough => [
+            {
+              "vendor_id"  => "8086",
+              "product_id" => "0126"
+            },
+            {
+              "vendor_id"        => "9096",
+              "product_id"       => "1520",
+              "physical_network" => "physnet1"
+            }
+          ],
+        }
+      end
 
-    context 'when vcpu_pin_set and pci_passthrough are empty' do
+      it 'configures nova pci_passthrough_whitelist entries' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
+          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
+        )
+      end
+    end
+
+    context 'with pci params JSON encoded string (deprecated)' do
+      let :params do
+        {
+          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
+        }
+      end
+
+      it 'configures nova pci_passthrough_whitelist entries' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
+          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
+        )
+      end
+    end
+
+    context 'when vcpu_pin_set and pci params are empty' do
       let :params do
         { :vcpu_pin_set    => "",
-          :pci_passthrough => "" }
+          :pci_passthrough => ""}
       end
 
       it 'clears vcpu_pin_set configuration' do
         is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>')
       end
       it 'clears pci_passthrough configuration' do
-        is_expected.to contain_nova_config('DEFAULT/pci_passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
       end
     end
 
